<h1>Library Subject Guide</h1>
<ul>
    {% url 'restclients_customform' 'libcurrics' 'course.html' as course_url %}
    {% if course_url %}
    <li><b><a href="{{ course_url }}">Course Guide</a></b></li>
    {% endif %}

    {% url 'restclients_customform' 'libcurrics' 'default.html' as defaultGuide_url %}
    {% if defaultGuide_url %}
    <li><b><a href="{{ defaultGuide_url }}">Default Guide</a></b></li>
    {% endif %}

</ul>
