<div><label for="transcriptable_course">Transcriptable Course:</label> <select class="transcriptable_course" id="transcriptable_course" name="transcriptable_course"><option value="all"{% if search.transcriptable_course == 'all' %} selected="selected"{% endif %}>All</option><option value="yes"{% if search.transcriptable_course == 'yes' %} selected="selected"{% endif %}>Yes</option><option value="no"{% if search.transcriptable_course == 'no' %} selected="selected"{% endif %}>No</option></select></div>
