<h1>My Library Info</h1>
<form method="post" action="{{form_action}}">
{% csrf_token %}
  <div>
    <label for="uwnetid">UW NetID:</label>
    <input id="uwnetid" name="id" size="64" type="text">
  </div>
  <div>
    <input value="Submit" type="submit">
  </div>
</form>
