<h1>Campus Default Guide Request</h1>
<form method="post" action="{{form_action}}">
{% csrf_token %}

    <div class="form-group">
    Campus:
    <select name="campus" maxlength="7">
        <option value="seattle">seattle</option>
        <option value="bothell">bothell</option>
        <option value="tacoma">tacoma</option>
    </select>
    <input type="submit" value="Go" class="btn btn-primary btn-sm">
    </div>
</form>
